@@ -7,18 +7,19 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
 use PHPUnit\Framework\TestCase;
 
-/*
- * This file is part of PHPUnit.
- *
- * (c) Sebastian Bergmann <sebastian@phpunit.de>
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
 class Issue2830Test extends TestCase
 {
+    public static function simpleDataProvider()
+    {
+        return [
+            ['foo'],
+        ];
+    }
+
     /**
      * @dataProvider simpleDataProvider
      */
@@ -26,11 +27,4 @@ class Issue2830Test extends TestCase
     {
         $this->assertTrue(true);
     }
-
-    public function simpleDataProvider()
-    {
-        return [
-            ['foo'],
-        ];
-    }
 }
