@@ -7,10 +7,18 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
+use Exception;
 use PHPUnit\Framework\TestCase;
 
 class Issue765Test extends TestCase
 {
+    public static function dependentProvider(): void
+    {
+        throw new Exception;
+    }
+
     public function testDependee(): void
     {
         $this->assertTrue(true);
@@ -25,9 +33,4 @@ class Issue765Test extends TestCase
     {
         $this->assertTrue(true);
     }
-
-    public function dependentProvider(): void
-    {
-        throw new Exception;
-    }
 }
