@@ -25,13 +25,15 @@ final class PhpNoticeTriggeredTest extends AbstractEventTestCase
         $message       = 'message';
         $file          = 'file';
         $line          = 1;
+        $suppressed    = false;
 
         $event = new PhpNoticeTriggered(
             $telemetryInfo,
             $test,
             $message,
             $file,
-            $line
+            $line,
+            $suppressed,
         );
 
         $this->assertSame($telemetryInfo, $event->telemetryInfo());
@@ -39,6 +41,7 @@ final class PhpNoticeTriggeredTest extends AbstractEventTestCase
         $this->assertSame($message, $event->message());
         $this->assertSame($file, $event->file());
         $this->assertSame($line, $event->line());
+        $this->assertSame($suppressed, $event->wasSuppressed());
         $this->assertSame('Test Triggered PHP Notice (FooTest::testBar)' . PHP_EOL . 'message', $event->asString());
     }
 }
