@@ -33,10 +33,20 @@ final class SourceMapperTest extends TestCase
                     FileCollection::fromArray(
                         [
                             new File($fixtureDirectory . '/a/PrefixSuffix.php'),
-                        ]
+                        ],
                     ),
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray([]),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using file, but excluded using directory' => [
@@ -47,18 +57,28 @@ final class SourceMapperTest extends TestCase
                     FileCollection::fromArray(
                         [
                             new File($fixtureDirectory . '/a/PrefixSuffix.php'),
-                        ]
+                        ],
                     ),
                     FilterDirectoryCollection::fromArray(
                         [
                             new FilterDirectory(
                                 $fixtureDirectory . '/a',
                                 '',
-                                '.php'
+                                '.php',
                             ),
-                        ]
+                        ],
                     ),
                     FileCollection::fromArray([]),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using file, but excluded using file' => [
@@ -69,14 +89,24 @@ final class SourceMapperTest extends TestCase
                     FileCollection::fromArray(
                         [
                             new File($fixtureDirectory . '/a/PrefixSuffix.php'),
-                        ]
+                        ],
                     ),
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray(
                         [
                             new File($fixtureDirectory . '/a/PrefixSuffix.php'),
-                        ]
+                        ],
                     ),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory' => [
@@ -100,13 +130,23 @@ final class SourceMapperTest extends TestCase
                             new FilterDirectory(
                                 $fixtureDirectory,
                                 '',
-                                '.php'
+                                '.php',
                             ),
-                        ]
+                        ],
                     ),
                     FileCollection::fromArray([]),
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray([]),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory, but excluded using file' => [
@@ -129,17 +169,27 @@ final class SourceMapperTest extends TestCase
                             new FilterDirectory(
                                 $fixtureDirectory,
                                 '',
-                                '.php'
+                                '.php',
                             ),
-                        ]
+                        ],
                     ),
                     FileCollection::fromArray([]),
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray(
                         [
                             new File($fixtureDirectory . '/a/PrefixSuffix.php'),
-                        ]
+                        ],
                     ),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory, but excluded using directory' => [
@@ -156,9 +206,9 @@ final class SourceMapperTest extends TestCase
                             new FilterDirectory(
                                 $fixtureDirectory,
                                 '',
-                                '.php'
+                                '.php',
                             ),
-                        ]
+                        ],
                     ),
                     FileCollection::fromArray([]),
                     FilterDirectoryCollection::fromArray(
@@ -166,11 +216,21 @@ final class SourceMapperTest extends TestCase
                             new FilterDirectory(
                                 $fixtureDirectory . '/a',
                                 '',
-                                '.php'
+                                '.php',
                             ),
-                        ]
+                        ],
                     ),
                     FileCollection::fromArray([]),
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
+                    false,
                 ),
             ],
         ];
